@@ -42,7 +42,6 @@ class RequestData:
 
 class DSRequest(RPCRequest):
     alive_only = None
-    tag = None
     begdate = None
     dataPageSize = 75
     drawAheadRatio = 1.2
@@ -50,64 +49,92 @@ class DSRequest(RPCRequest):
     enddate = None
     endRow = None
     startRow = None
+    tag = None
+    user = None
     visibleMode = 'none'
 
+    def check_old(self, request):
+        from isc_common.auth.models.user import User
+        if self.user == None:
+            self.username = request.session._session.get('username')
+            self.user_id = request.session._session.get('user_id')
+
+            try:
+                self.ws_channel = request.GET.get('ws_channel')
+                self.ws_port = request.GET.get('ws_port')
+                self.host = request.GET.get('host')
+
+                if self.user_id == None:
+                    self.user_id = request.GET.get('user_id')
+
+                if self.user_id == None and self.ws_channel != None:
+                    self.user_id = User.objects.get(username=self.ws_channel.split('_')[1]).id
+                if self.user_id != None:
+                    self.user = User.objects.get(id=self.user_id)
+                    self.is_admin = self.user.is_admin
+                    self.is_develop = self.user.is_develop
+                else:
+                    self.user = None
+            except User.DoesNotExist:
+                self.user = None
+
+            if self.is_admin == None:
+                self.is_admin = request.session._session.get('is_admin')
+
+            if self.is_develop == None:
+                self.is_develop = request.session._session.get('is_develop')
+
+            if self.ws_channel == None:
+                self.ws_channel = request.session._session.get('ws_channel')
+
+            if self.ws_port == None:
+                self.ws_port = request.session._session.get('ws_port')
+
+            if self.host == None:
+                self.host = request.session._session.get('host')
+
     def __init__(self, request):
         from isc_common.auth.models.user import User
 
         self.json = None
 
-        if request != None and request.body != b'':
-            self.json = BytesToJson(request.body)
+        if request != None:
+            if request.body != b'':
+                self.json = BytesToJson(request.body)
 
-            data = self.json.get('data')
-            self.user = None
-            if isinstance(data, dict):
-                httpHeaders = data.get('httpHeaders')
-                if isinstance(httpHeaders, dict):
-                    if httpHeaders.get('WS_CHANNEL') != None:
-                        self.ws_channel = httpHeaders.get('WS_CHANNEL')
+                data = self.json.get('data')
+                self.user = None
+                if isinstance(data, dict):
+                    httpHeaders = data.get('httpHeaders')
+                    if isinstance(httpHeaders, dict):
+                        if httpHeaders.get('WS_CHANNEL') != None:
+                            self.ws_channel = httpHeaders.get('WS_CHANNEL')
 
-                    if httpHeaders.get('WS_PORT') != None:
-                        self.ws_port = httpHeaders.get('WS_PORT')
+                        if httpHeaders.get('WS_PORT') != None:
+                            self.ws_port = httpHeaders.get('WS_PORT')
 
-                    if httpHeaders.get('HOST') != None:
-                        self.host = httpHeaders.get('HOST')
+                        if httpHeaders.get('HOST') != None:
+                            self.host = httpHeaders.get('HOST')
 
-                    if httpHeaders.get('USERNAME') != None:
-                        self.username = httpHeaders.get('USERNAME')
+                        if httpHeaders.get('USERNAME') != None:
+                            self.username = httpHeaders.get('USERNAME')
 
-                    if httpHeaders.get('USER_ID') != None:
-                        # print(f'''USER_ID: {httpHeaders.get('USER_ID')}''')
-                        self.user_id = httpHeaders.get('USER_ID')
-                        self.user = User.objects.get(id=self.user_id)
+                        if httpHeaders.get('USER_ID') != None:
+                            # print(f'''USER_ID: {httpHeaders.get('USER_ID')}''')
+                            self.user_id = httpHeaders.get('USER_ID')
+                            self.user = User.objects.get(id=self.user_id)
 
-                    if httpHeaders.get('IS_ADMIN') != None:
-                        self.is_admin = httpHeaders.get('IS_ADMIN')
+                        if httpHeaders.get('IS_ADMIN') != None:
+                            self.is_admin = httpHeaders.get('IS_ADMIN')
 
-                    if httpHeaders.get('IS_DEVELOP') != None:
-                        self.is_develop = httpHeaders.get('IS_DEVELOP')
+                        if httpHeaders.get('IS_DEVELOP') != None:
+                            self.is_develop = httpHeaders.get('IS_DEVELOP')
 
-                    delAttr(self.json.get('data'), 'httpHeaders')
+                        delAttr(self.json.get('data'), 'httpHeaders')
 
-            if self.user == None:
-                self.username = request.session._session.get('username')
-                self.user_id = request.session._session.get('user_id')
-
-                try:
-                    if self.user_id == None and request.GET.get('ws_channel') != None:
-                        self.user_id = User.objects.get(username=request.GET.get('ws_channel').split('_')[1]).id
-                    if self.user_id != None:
-                        self.user = User.objects.get(id=self.user_id)
-                    else:
-                        self.user = None
-                except User.DoesNotExist:
-                    self.user = None
-                self.is_admin = request.session._session.get('is_admin')
-                self.is_develop = request.session._session.get('is_develop')
-                self.ws_channel = request.session._session.get('ws_channel')
-                self.ws_port = request.session._session.get('ws_port')
-                self.host = request.session._session.get('host')
+                self.check_old(request=request)
+            else:
+                self.check_old(request=request)
 
         RPCRequest.__init__(self, self.json)
 
