@@ -286,6 +286,16 @@ class CommonQuerySet(QuerySet):
 
         return res
 
+    def delete_underscore_element(self, data):
+        if not isinstance(data, dict):
+            raise Exception('data must be dict')
+
+        res = dict()
+        for key, value in data.items():
+            if str(key).find('_', 0, 1) == -1:
+                setAttr(res, key, value)
+        return res
+
     def get_criteria(self, json=dict()):
         data = json.get('data', dict())
         _data = dict()
@@ -487,6 +497,7 @@ class CommonQuerySet(QuerySet):
         cnt_all = super().filter().count()
         return dict(qty_rows=cnt, all_rows=cnt_all)
 
+
 class CommonManager(Manager):
     def refresh_mat_view(self, mat_view):
         with connection.cursor() as cursor:
