@@ -26,14 +26,8 @@ class AuditQuerySet(CommonQuerySet):
                             setAttr(json.get('data'), 'criteria', criteria_lst)
         return json
 
-    def soft_delete(self, visibleMode="hide"):
-        res = 0
-        if visibleMode == "hide":
-            res = super().update(deleted_at=timezone.now())
-        elif visibleMode == "visible":
-            logger.warning(f'!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!Mode visibleMode={visibleMode} DEPRECATED !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!')
-            res = super().update(deleted_at=None)
-
+    def soft_delete(self):
+        res = super().update(deleted_at=timezone.now())
         return res
 
     def soft_restore(self):
