@@ -1,8 +1,11 @@
 from decimal import Decimal
+from itertools import chain
 
 from bitfield import BitHandler, Bit
+from django.db.models import ForeignKey
 
 from isc_common import setAttr
+from isc_common.fields.related import ForeignKeyProtect
 
 
 def DecimalToStr(value):
@@ -117,3 +120,30 @@ def GetPropsInt(value):
         return value._value
     else:
         value
+
+def model_2_dict(instance, fields=None, exclude=None):
+    """
+    Return a dict containing the data in ``instance`` suitable for passing as
+    a Form's ``initial`` keyword argument.
+
+    ``fields`` is an optional list of field names. If provided, return only the
+    named.
+
+    ``exclude`` is an optional list of field names. If provided, exclude the
+    named from the returned dict, even if they are listed in the ``fields``
+    argument.
+    """
+    opts = instance._meta
+    data = {}
+    for f in chain(opts.concrete_fields, opts.private_fields, opts.many_to_many):
+        if not getattr(f, 'editable', False):
+            continue
+        if fields is not None and f.name not in fields:
+            continue
+        if exclude and f.name in exclude:
+            continue
+        if isinstance(f, ForeignKey):
+            data[f'{f.name}_id'] = f.value_from_object(instance)
+        else:
+            data[f.name] = f.value_from_object(instance)
+    return data
